@@ -1,6 +1,6 @@
 package Mojo::Redis;
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 use Mojo::Base 'Mojo::EventEmitter';
 
 use Mojo::IOLoop;
@@ -490,8 +490,9 @@ L<Mojo::Redis> is replaced by L<Mojo::Redis2>.
 THIS MODULE IS NO LONGER MAINTAINED AND WILL BE REPLACED BY A COMPLETELY NEW
 API DURING 2015.
 
-The new API is available in L<Mojo::Redis2>. Some time during 2015, this
-module will be completely replaced by the code from L<Mojo::Redis2>.
+The new API is available in L<Mojo::Redis2>.
+
+Some time during 2015, this module will be completely replaced by the code from L<Mojo::Redis2>.
 
 YOU SHOULD NOT USE THIS MODULE. THE RISK OF MEMORY LEAKS AND MISSING OUT ON
 ERRORS IS INEVITABLE.
@@ -501,200 +502,9 @@ existing L<Mojo::Redis> code I<will> break.
 
 REPLACE L<Mojo::Redis> WITH L<Mojo::Redis2> NOW.
 
-=head1 EVENTS
-
-=head2 blpop
-
-  $cb = $redis->on(blpop => @list_names => sub {
-    my($redis, $err, $data, $list_name) = @_;
-    warn "[REDIS BLPOP] Got ($data) from $list_name\n";
-  });
-
-This is a special event which allow you to do recurring L</blpop> without
-blocking the current L<Mojo::Redis> object. Recurring means that once
-the callback has handled the data, it will issue a new BLPOP.
-
-One of the commands below is required to stop the BLPOP loop:
-
-  $redis->on(message => @channels);
-  $redis->on(message => @channels => $cb);
-
-=head2 brpop
-
-See L</blpop>.
-
-=head2 error
-
-  $redis->on(error => sub {
-    my($redis, $error) = @_;
-    warn "[REDIS ERROR] $error\n";
-  });
-
-Emitted if error occurred. Called before commands callbacks.
-
-=head2 close
-
-  $redis->on(close => sub {
-    my($redis) = @_;
-    warn "[REDIS DISCONNECT]\n";
-  });
-
-Emitted when the connection to the server gets closed.
-
-=head2 message
-
-  $redis->on(message => @channels => sub {
-    my($redis, $err, $message, $channel) = @_;
-    warn "[REDIS PUBSUB] Got ($message) from $channel\n";
-  });
-
-This is a special event which allow you to L</subscribe> to messages directly
-in the current L<Mojo::Redis> object instead of using a new
-L<Mojo::Redis::Subscription> object.
-
-To unsubscribe you need to do one of these:
-
-  $redis->on(message => @channels);
-  $redis->on(message => @channels => $cb);
-
-=head1 ATTRIBUTES
-
-L<Mojo::Redis> implements the following attributes.
-
-=head2 connected
-
-=head2 encoding
-
-  $encoding = $redis->encoding;
-  $redis    = $redis->encoding('UTF-8');
-
-Encoding used for stored data, defaults to C<UTF-8>.
-
-=head2 ioloop
-
-=head2 protocol
-
-=head2 protocol_redis
-
-  use Protocol::Redis::XS;
-  $redis->protocol_redis("Protocol::Redis::XS");
-
-L<Protocol::Redis> implementation' constructor for parsing. By default
-L<Protocol::Redis> will be used. Parser library must support
-L<APIv1|Protocol::Redis/APIv1>.
-
-Using L<Protocol::Redis::XS> instead of default choice can speedup parsing.
-
-=head2 server
-
-  $server = $redis->server;
-  $redis  = $redis->server('127.0.0.1:6379');
-  $redis  = $redis->server('redis://anything:PASSWORD@127.0.0.1:6379/DB_INDEX');
-
-C<Redis> server connection string, defaults to "127.0.0.1:6379". The
-latter can be used if you want L<Mojo::Redis> to automatically run L</auth>
-with C<PASSWORD> and/or L</select> with C<DB_INDEX> on connect. Both AUTH
-and DB_INDEX are optional.
-
-=head2 timeout
-
-  $seconds = $redis->timeout;
-  $redis   = $redis->timeout(100);
-
-Maximum amount of time in seconds a connection can be inactive before being
-dropped, defaults to C<0> - meaning no timeout.
-
-=head1 METHODS
-
-=head2 connect
-
-  $redis = $redis->connect;
-
-Connect to C<Redis> server.
-
-=head2 disconnect
-
-  $redis = $self->disconnect;
-
-Used to disconnect from the server. This method is automatically called when
-this object goes out of scope.
-
-=head2 execute
-
-  $redis = $redis->execute("ping" => sub {
-             my ($redis, $result) = @_;
-             # Process $result
-           });
-
-  $redis->execute(lrange => "test", 0, -1 => sub {...});
-  $redis->execute(set => test => "test_ok");
-
-  $redis->execute(
-    [lrange => "test", 0, -1],
-    [get => "test"],
-    [hmset => foo => { one => 1, two => 2 }],
-    sub {
-      my($redis, $lrange, $get, $hmset) = @_;
-      # ...
-    },
-  );
-
-Execute specified command on C<Redis> server. If error occurred during
-request $result will be set to undef, error string can be obtained with
-the L</error> event.
-
-=head2 on
-
-Same as L<Mojo::EventEmitter/on>, except it allows special events such as
-L</blpop>, L</brpop> and L</message>.
-
-=head2 once
-
-Same as L<Mojo::EventEmitter/once>, except it allows special events such as
-L</blpop>, L</brpop> and L</message>.
-
-=head2 psubscribe
-
-Subscribes to channels matching the given patterns.
-
-  # Subscribes to foo, foobar, foo.whaz, etc.
-  my $psub = $redis->psubscribe('foo*');
-  $psub->on(message => sub {
-    my ($self, $msg, $channel, $pattern) = @_; # 'hi!', 'foo.roo', 'foo*'
-  });
-
-  $redis->publish('foo.roo' => 'hi!');
-
-L</psubscribe> has the same interface options and capabilities as L</subscribe>.
-
-=head2 subscribe
-
-It's possible to subscribe in two ways:
-
-  $redis = $redis->subscribe('foo','bar' => sub {
-             my ($redis, $data) = @_;
-           });
-
-The above code will overtake the current connection (if any) and put this
-object into a pure subscribe mode.
-
-  my $sub = $redis->subscribe('foo','bar');
-  $sub->on(data => sub {
-    my ($sub, $data) = @_;
-  });
-
-Opens up a new connection that subscribes to the given pubsub channels.
-Returns an instance of L<Mojo::Redis::Subscription>. The existing C<$redis>
-object can still be used to L</get> data as expected.
-
-=head2 unsubscribe
-
-The opposite as L</on>. See also L<Mojo::EventEmitter/unsubscribe>.
-
 =head1 SUPPORT
 
-You can contact the developers "marcus" and "batman" on IRC:
-L<irc://irc.perl.org:6667/#mojo> (#mojo on irc.perl.org)
+There's no support for this module.
 
 =head1 AUTHOR
 
